==> jk_smallgraph-0.2022.7.30.tar.gz: jk_smallgraph-0.2022.7.30/jk_smallgraph/Link.py <==


import os
import typing

import jk_typing


from .INode import INode
from .ILink import ILink






class Link(ILink):

	################################################################################################################################
	## Constructor
	################################################################################################################################

	#
	# Constructor method.
	#
	@jk_typing.checkFunctionSignature()
	def __init__(self, graph, linkID:int, fromNode:INode, toNode:INode):
		self._graph = graph
		self._linkID = linkID
		self._fromNode = fromNode
		self._toNode = toNode
	#

	################################################################################################################################
	## Public Properties
	################################################################################################################################

	@property
	def linkID(self) -> int:
		return self._linkID
	#

	@property
	def fromNode(self) -> INode:
		return self._fromNode
	#

	@property
	def toNode(self) -> INode:
		return self._toNode
	#

	################################################################################################################################
	## Helper Methods
	################################################################################################################################

	################################################################################################################################
	## Public Methods
	################################################################################################################################

	def __str__(self):
		return "Link<({}, {}->{})>".format(self._linkID, repr(self._fromNode._name), repr(self._toNode._name))
	#

	def __repr__(self):
		return "Link<({}, {}->{})>".format(self._linkID, repr(self._fromNode._name), repr(self._toNode._name))
	#

	def __hash__(self) -> int:
		return self._linkID.__hash__()
	#

#

==> jk_smallgraph-0.2024.5.25.tar.gz: jk_smallgraph-0.2024.5.25/jk_smallgraph/Link.py <==


import os
import typing

import jk_typing


from .INode import INode
from .ILink import ILink






class Link(ILink):

	################################################################################################################################
	## Constructor
	################################################################################################################################

	#
	# Constructor method.
	#
	@jk_typing.checkFunctionSignature()
	def __init__(self, graph, linkID:int, fromNode:INode, toNode:INode):
		self.__graph = graph
		self.__linkID = linkID
		self.__fromNode = fromNode
		self.__toNode = toNode
		self.__tag = None
	#

	################################################################################################################################
	## Public Properties
	################################################################################################################################

	@property
	def linkID(self) -> int:
		return self.__linkID
	#

	@property
	def fromNode(self) -> INode:
		return self.__fromNode
	#

	@property
	def toNode(self) -> INode:
		return self.__toNode
	#

	@property
	def tag(self) -> typing.Any:
		return self.__tag
	#

	@tag.setter
	def tag(self, tag:typing.Any):
		self.__tag = tag
	#

	################################################################################################################################
	## Helper Methods
	################################################################################################################################

	################################################################################################################################
	## Public Methods
	################################################################################################################################

	def __str__(self):
		return "Link<({}, {}->{})>".format(self.__linkID, repr(self.__fromNode._name), repr(self.__toNode._name))
	#

	def __repr__(self):
		return "Link<({}, {}->{})>".format(self.__linkID, repr(self.__fromNode._name), repr(self.__toNode._name))
	#

	def __hash__(self) -> int:
		return self.__linkID.__hash__()
	#

#
